<!-- Common snippets and abbreviations for Velithon documentation -->

*[RSGI]: Rust Server Gateway Interface
*[ASGI]: Asynchronous Server Gateway Interface  
*[API]: Application Programming Interface
*[HTTP]: Hypertext Transfer Protocol
*[JSON]: JavaScript Object Notation
*[JWT]: JSON Web Token
*[CRUD]: Create, Read, Update, Delete
*[CLI]: Command Line Interface
*[SSL]: Secure Sockets Layer
*[TLS]: Transport Layer Security
*[CORS]: Cross-Origin Resource Sharing
*[SSE]: Server-Sent Events
*[DI]: Dependency Injection
*[ORM]: Object-Relational Mapping
*[WebSocket]: WebSocket Protocol
